pub struct EmbeddedFileSystem { /* private fields */ }Trait Implementations
Sourceimpl FileSystem for EmbeddedFileSystem
impl FileSystem for EmbeddedFileSystem
fn read(self: Vc<Self>, path: FileSystemPath) -> Vc<FileContent>
Sourcefn read_link(self: Vc<Self>, _path: FileSystemPath) -> Vc<LinkContent>
fn read_link(self: Vc<Self>, _path: FileSystemPath) -> Vc<LinkContent>
Reads the target of a symbolic link (or junction point on Windows). See
LinkContent.Sourcefn is_junction_point(self: Vc<Self>, _path: FileSystemPath) -> Vc<bool>
fn is_junction_point(self: Vc<Self>, _path: FileSystemPath) -> Vc<bool>
Returns whether a symbolic link is a junction point on Windows. Always
false on all other
platforms.fn raw_read_dir(self: Vc<Self>, path: FileSystemPath) -> Vc<RawDirectoryContent>
fn write( self: Vc<Self>, _path: FileSystemPath, _content: Vc<FileContent>, ) -> Vc<()>
Sourcefn write_link(
self: Vc<Self>,
_path: FileSystemPath,
_target: Vc<WriteLinkContent>,
) -> Vc<()>
fn write_link( self: Vc<Self>, _path: FileSystemPath, _target: Vc<WriteLinkContent>, ) -> Vc<()>
Creates a symbolic link. See
WriteLinkContent and FileSystemPath::write_link.fn metadata(self: Vc<Self>, path: FileSystemPath) -> Vc<FileMeta>
Sourcefn root(self: Vc<Self>) -> Vc<FileSystemPath>where
Self: Sized,
fn root(self: Vc<Self>) -> Vc<FileSystemPath>where
Self: Sized,
Returns the path to the root of the file system.
impl NonLocalValue for EmbeddedFileSystem
Sourceimpl ShrinkToFit for EmbeddedFileSystem
impl ShrinkToFit for EmbeddedFileSystem
fn shrink_to_fit(&mut self)
Sourceimpl TraceRawVcs for EmbeddedFileSystem
impl TraceRawVcs for EmbeddedFileSystem
fn trace_raw_vcs(&self, __context__: &mut TraceRawVcsContext)
fn get_raw_vcs(&self) -> Vec<RawVc>
impl Upcast<Box<dyn FileSystem>> for EmbeddedFileSystem
impl Upcast<Box<dyn ValueDebug>> for EmbeddedFileSystem
impl Upcast<Box<dyn ValueToString>> for EmbeddedFileSystem
impl UpcastStrict<Box<dyn FileSystem>> for EmbeddedFileSystem
impl UpcastStrict<Box<dyn ValueDebug>> for EmbeddedFileSystem
impl UpcastStrict<Box<dyn ValueToString>> for EmbeddedFileSystem
Sourceimpl ValueDebug for EmbeddedFileSystem
impl ValueDebug for EmbeddedFileSystem
Sourceimpl ValueDebugFormat for EmbeddedFileSystem
Available on debug-assertions enabled only.
impl ValueDebugFormat for EmbeddedFileSystem
Available on debug-assertions enabled only.
fn value_debug_format<'a>(&'a self, depth: usize) -> ValueDebugFormatString<'a>
Sourceimpl ValueToStringRef for EmbeddedFileSystem
impl ValueToStringRef for EmbeddedFileSystem
async fn to_string_ref(&self) -> Result<RcStr>
Sourceimpl VcValueType for EmbeddedFileSystem
impl VcValueType for EmbeddedFileSystem
Sourcetype Read = VcDefaultRead<EmbeddedFileSystem>
type Read = VcDefaultRead<EmbeddedFileSystem>
How to read the value.
Sourcetype CellMode = VcCellNewMode<EmbeddedFileSystem>
type CellMode = VcCellNewMode<EmbeddedFileSystem>
How to update cells of this value type.
Sourcefn get_value_type_id() -> ValueTypeId
fn get_value_type_id() -> ValueTypeId
Returns the type id of the value type.
fn has_serialization() -> bool