pub enum DiskWatcherRecursiveMode {
Recursive,
NonRecursive,
}Expand description
Equivalent to [notify::RecursiveMode], but implements traits needed by [turbo_tasks].
When using Self::Recursive, [notify::Watcher] will recursively track all contents
of the filesystem root. This should only be used on platforms with efficient recursive watcher
implementations (i.e. macOS and Windows).
When using Self::NonRecursive, we only track previously read files and their parent
directories.
Variants