pub enum FileContent {
Content(File),
NotFound,
}Variants
Implementations
Sourceimpl FileContent
impl FileContent
Sourcepub fn cell(self) -> Vc<Self>
pub fn cell(self) -> Vc<Self>
Places a value in a cell of the current task.
Cell is selected based on the value type and call order of cell.
Sourcepub fn resolved_cell(self) -> ResolvedVc<Self>
pub fn resolved_cell(self) -> ResolvedVc<Self>
Places a value in a cell of the current task. Returns a
[ResolvedVc][turbo_tasks::ResolvedVc].
Cell is selected based on the value type and call order of cell.
Sourceimpl FileContent
impl FileContent
pub fn new(file: File) -> Self
pub fn is_content(&self) -> bool
pub fn as_content(&self) -> Option<&File>
pub fn parse_json_ref(&self) -> FileJsonContent
pub fn parse_json_with_comments_ref(&self) -> FileJsonContent
pub fn parse_json5_ref(&self) -> FileJsonContent
pub fn lines_ref(&self) -> FileLinesContent
Sourceimpl FileContent
impl FileContent
pub fn len(self: Vc<Self>) -> Vc<Option<u64>>
pub fn parse_json(self: Vc<Self>) -> Vc<FileJsonContent>
pub fn parse_json_with_comments(self: Vc<Self>) -> Vc<FileJsonContent>
pub fn parse_json5(self: Vc<Self>) -> Vc<FileJsonContent>
pub fn lines(self: Vc<Self>) -> Vc<FileLinesContent>
pub fn hash(self: Vc<Self>, algorithm: HashAlgorithm) -> Vc<RcStr>
Sourcepub fn persist(self: Vc<Self>) -> Vc<PersistedFileContent>
pub fn persist(self: Vc<Self>) -> Vc<PersistedFileContent>
Converts this FileContent into a PersistedFileContent by cloning.
Use this in contexts where the full file content must be serialized to the persistent
task cache (e.g., in DiskFileSystem::write).
Sourcepub fn content_hash(
self: Vc<Self>,
salt: Vc<RcStr>,
algorithm: HashAlgorithm,
) -> Vc<Option<RcStr>>
pub fn content_hash( self: Vc<Self>, salt: Vc<RcStr>, algorithm: HashAlgorithm, ) -> Vc<Option<RcStr>>
Compared to FileContent::hash, this hashes only the bytes of the file content and
nothing else, returning None if the file does not exist.
If salt is non-empty it is written into the hasher before the file bytes in a single
pass. An empty salt produces the same result as hashing without a prefix.