pub enum FileJsonContent {
Content(Value),
Unparsable(Box<UnparsableJson>),
NotFound,
}Expand description
A file’s content interpreted as a JSON value.
Variants
Implementations
Sourceimpl FileJsonContent
impl FileJsonContent
Sourcepub fn cell(self) -> Vc<Self>
pub fn cell(self) -> Vc<Self>
Places a value in a cell of the current task.
Cell is selected based on the value type and call order of cell.
Sourcepub fn resolved_cell(self) -> ResolvedVc<Self>
pub fn resolved_cell(self) -> ResolvedVc<Self>
Places a value in a cell of the current task. Returns a
[ResolvedVc][turbo_tasks::ResolvedVc].
Cell is selected based on the value type and call order of cell.
Sourceimpl FileJsonContent
impl FileJsonContent
pub fn unparsable(message: RcStr) -> Self
pub fn unparsable_with_message(message: RcStr) -> Self