FileLinesContent

Enum FileLinesContent 

pub enum FileLinesContent {
    Lines(Vec<FileLine>),
    Unparsable,
    NotFound,
}

Variants



Lines(Vec<FileLine>)



Unparsable



NotFound

Implementations

Source

impl FileLinesContent

pub fn cell(self) -> Vc<Self>

Places a value in a cell of the current task.

Cell is selected based on the value type and call order of cell.

pub fn resolved_cell(self) -> ResolvedVc<Self>

Places a value in a cell of the current task. Returns a [ResolvedVc][turbo_tasks::ResolvedVc].

Cell is selected based on the value type and call order of cell.