PersistedFileContent

Enum PersistedFileContent 

pub enum PersistedFileContent {
    Content(File),
    NotFound,
}
A persisted version of FileContent that stores the full file content in the task cache.

FileContent uses serialization = "hash", so only a hash is kept in the persistent cache. When reading the file content back from the cache, the hash is compared to detect changes, but the actual data is not available. PersistedFileContent provides the full data so that DiskFileSystem::write can retrieve it without re-reading from disk.

Variants



Content(File)



NotFound

Implementations

Source

impl PersistedFileContent

pub fn cell(self) -> Vc<Self>

Places a value in a cell of the current task.

Cell is selected based on the value type and call order of cell.

pub fn resolved_cell(self) -> ResolvedVc<Self>

Places a value in a cell of the current task. Returns a [ResolvedVc][turbo_tasks::ResolvedVc].

Cell is selected based on the value type and call order of cell.