pub enum RealPathErrorType {
TooManySymlinks {
symlinks: Box<[FileSystemPath]>,
},
CycleDetected {
symlinks: Box<[FileSystemPath]>,
},
NotFound,
Invalid {
reason: RcStr,
},
}Variants
TooManySymlinks
Fields

symlinks: Box<[FileSystemPath]>CycleDetected
Fields

symlinks: Box<[FileSystemPath]>NotFound
A symlink or path component does not exist.
Invalid
Resolution failed after finding a symlink, or the symlink was invalid to begin with.
Fields

reason: RcStrTrait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for RealPathErrorType
impl<'__de, __Context> BorrowDecode<'__de, __Context> for RealPathErrorType
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for RealPathErrorType
impl Clone for RealPathErrorType
Sourcefn clone(&self) -> RealPathErrorType
fn clone(&self) -> RealPathErrorType
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RealPathErrorType
impl Debug for RealPathErrorType
Sourceimpl<__Context> Decode<__Context> for RealPathErrorType
impl<__Context> Decode<__Context> for RealPathErrorType
Sourceimpl Encode for RealPathErrorType
impl Encode for RealPathErrorType
impl Eq for RealPathErrorType
Sourceimpl Hash for RealPathErrorType
impl Hash for RealPathErrorType
impl NonLocalValue for RealPathErrorType
Sourceimpl PartialEq for RealPathErrorType
impl PartialEq for RealPathErrorType
impl StructuralPartialEq for RealPathErrorType