pub enum WriteLinkTargetType {
FileNonPortable,
DirectoryOrJunctionPoint,
}Expand description
The file type of the target of a newly written link. This value is only used on Windows.
Variants
FileNonPortable
Represents a link to a file or a symbolic link that is not a junction point. This is likely to fail on Windows, where symbolic links are not enabled by default.
DirectoryOrJunctionPoint
Represents a link to a directory. On Windows, this may also be a link to a junction point.