pub struct GlobOptions {
pub contains: bool,
pub case_insensitive: bool,
}Fields
contains: boolWhether the glob is a partial match.
Allows glob to match any part of the given string(s).
NOTE: this means that a pattern like node_modules/package_name with contains:true will
match foo_node_modules/package_name_bar If you want to match a directory named
node_modules/package_name you should use **/node_modules/package_name/**
case_insensitive: boolWhether matching should ignore ASCII case differences.