pub struct RealPathError { /* private fields */ }Expand description
Errors that can occur when resolving a path with symlinks. Many of these can be transient conditions that might happen when package managers are running.
Implementations
Sourceimpl RealPathError
impl RealPathError
pub fn kind(&self) -> &RealPathErrorType