pub struct RealPathWithLinksResult {
pub path_result: Result<FileSystemPath, RealPathError>,
pub symlinks: Box<[FileSystemPath]>,
}Fields
path_result: Result<FileSystemPath, RealPathError>symlinks: Box<[FileSystemPath]>Implementations
Sourceimpl RealPathWithLinksResult
impl RealPathWithLinksResult
Sourcepub fn cell(self) -> Vc<Self>
pub fn cell(self) -> Vc<Self>
Places a value in a cell of the current task.
Cell is selected based on the value type and call order of cell.
Sourcepub fn resolved_cell(self) -> ResolvedVc<Self>
pub fn resolved_cell(self) -> ResolvedVc<Self>
Places a value in a cell of the current task. Returns a
[ResolvedVc][turbo_tasks::ResolvedVc].
Cell is selected based on the value type and call order of cell.