pub struct VirtualFileSystem {
pub name: RcStr,
}Fields
name: RcStrImplementations
Sourceimpl VirtualFileSystem
impl VirtualFileSystem
Sourcepub fn new() -> Vc<Self>
pub fn new() -> Vc<Self>
Creates a new [Vc<VirtualFileSystem>].
NOTE: This function is not a turbo_tasks::function to avoid instances
being equivalent identity-wise. This ensures that a
FileSystemPath created from this [Vc<VirtualFileSystem>]
will never be equivalent, nor be interoperable, with a
FileSystemPath created from another
[Vc<VirtualFileSystem>].
Sourcepub fn new_with_name(name: RcStr) -> Vc<Self>
pub fn new_with_name(name: RcStr) -> Vc<Self>
Creates a new [Vc<VirtualFileSystem>] with a name.
NOTE: This function is not a turbo_tasks::function to avoid instances
being equivalent identity-wise. This ensures that a
FileSystemPath created from this [Vc<VirtualFileSystem>]
will never be equivalent, nor be interoperable, with a
FileSystemPath created from another
[Vc<VirtualFileSystem>].