pub struct WriteLinkContent {
pub target: WriteLinkTarget,
pub target_type: WriteLinkTargetType,
}Expand description
The symbolic link to create at a path, passed to FileSystemPath::write_link.
This is separate from LinkContent because writing needs to know whether the target is a
directory, while reading a link does not: on Windows we always create junction points for
directories, because symlink creation may fail if “developer mode” is not enabled and we’re
running in an unprivileged environment.
Fields
target: WriteLinkTargettarget_type: WriteLinkTargetTypeImplementations
Sourceimpl WriteLinkContent
impl WriteLinkContent
Sourcepub fn cell(self) -> Vc<Self>
pub fn cell(self) -> Vc<Self>
Places a value in a cell of the current task.
Cell is selected based on the value type and call order of cell.
Sourcepub fn resolved_cell(self) -> ResolvedVc<Self>
pub fn resolved_cell(self) -> ResolvedVc<Self>
Places a value in a cell of the current task. Returns a
[ResolvedVc][turbo_tasks::ResolvedVc].
Cell is selected based on the value type and call order of cell.