FileSystem

Trait FileSystem 

pub trait FileSystem:
    ValueToString
    + Send
    + Sync
    + NonLocalValue
    + ValueDebug {
    // Required methods
    fn read(self: Vc<Self>, fs_path: FileSystemPath) -> Vc<FileContent>
       where Self: Sized;
    fn read_link(self: Vc<Self>, fs_path: FileSystemPath) -> Vc<LinkContent>
       where Self: Sized;
    fn is_junction_point(self: Vc<Self>, fs_path: FileSystemPath) -> Vc<bool>
       where Self: Sized;
    fn raw_read_dir(
        self: Vc<Self>,
        fs_path: FileSystemPath,
    ) -> Vc<RawDirectoryContent>
       where Self: Sized;
    fn write(
        self: Vc<Self>,
        fs_path: FileSystemPath,
        content: Vc<FileContent>,
    ) -> Vc<()>
       where Self: Sized;
    fn write_link(
        self: Vc<Self>,
        fs_path: FileSystemPath,
        target: Vc<WriteLinkContent>,
    ) -> Vc<()>
       where Self: Sized;
    fn metadata(self: Vc<Self>, fs_path: FileSystemPath) -> Vc<FileMeta>
       where Self: Sized;

    // Provided method
    fn root(self: Vc<Self>) -> Vc<FileSystemPath>
       where Self: Sized { ... }
}

Required Methods

fn read(self: Vc<Self>, fs_path: FileSystemPath) -> Vc<FileContent>
where Self: Sized,

Reads the target of a symbolic link (or junction point on Windows). See LinkContent.

fn is_junction_point(self: Vc<Self>, fs_path: FileSystemPath) -> Vc<bool>
where Self: Sized,

Returns whether a symbolic link is a junction point on Windows. Always false on all other platforms.

fn raw_read_dir( self: Vc<Self>, fs_path: FileSystemPath, ) -> Vc<RawDirectoryContent>
where Self: Sized,

fn write( self: Vc<Self>, fs_path: FileSystemPath, content: Vc<FileContent>, ) -> Vc<()>
where Self: Sized,

Creates a symbolic link. See WriteLinkContent and FileSystemPath::write_link.

fn metadata(self: Vc<Self>, fs_path: FileSystemPath) -> Vc<FileMeta>
where Self: Sized,

Provided Methods

fn root(self: Vc<Self>) -> Vc<FileSystemPath>
where Self: Sized,

Returns the path to the root of the file system.