pub struct DiskFileSystem { /* private fields */ }Expand description
DiskFileSystem carries serializable fields (name, root,
denied_paths) inside DiskFileSystemInner alongside session-scoped
state (the notify watcher, invalidator maps, weak TurboTasksApi,
etc.) This is important to maintain invariants in a session and ensure invalidations work, so we
never evict this data.
Implementations
Sourceimpl DiskFileSystem
impl DiskFileSystem
pub fn name(&self) -> &RcStr
pub fn root(&self) -> &RcStr
pub fn invalidate(&self)
pub fn invalidate_with_reason<R: InvalidationReason + Clone>( &self, reason: impl Fn(&Path) -> R + Sync, )
pub fn invalidate_path_and_children_with_reason<R: InvalidationReason + Clone>( &self, paths: impl IntoIterator<Item = PathBuf>, reason: impl Fn(&Path) -> R + Sync, )
pub async fn start_watching( &self, poll_interval: Option<Duration>, ) -> Result<()>
pub async fn start_watching_with_invalidation_reason( &self, poll_interval: Option<Duration>, ) -> Result<()>
pub async fn stop_watching(&self)
Sourcepub fn try_from_sys_path(
&self,
vc_self: ResolvedVc<DiskFileSystem>,
sys_path: &Path,
relative_to: Option<&FileSystemPath>,
) -> Option<FileSystemPath>
pub fn try_from_sys_path( &self, vc_self: ResolvedVc<DiskFileSystem>, sys_path: &Path, relative_to: Option<&FileSystemPath>, ) -> Option<FileSystemPath>
Try to convert Path to FileSystemPath. Return None if the file path leaves the
filesystem root. If no relative_to argument is given, it is assumed that the sys_path is
relative to the DiskFileSystem root.
Attempts to convert absolute paths to paths relative to the filesystem root, though we only attempt to do so lexically.
Assumes self is the DiskFileSystem contained in vc_self. This API is a bit awkward
because:
Path/PathBufshould not be stored in the filesystem cache, so the function cannot be aturbo_tasks::function.- It’s a little convenient for this function to be sync.
pub fn to_sys_path(&self, fs_path: &FileSystemPath) -> PathBuf
Sourceimpl DiskFileSystem
impl DiskFileSystem
Sourcepub fn new(name: RcStr, root: Vc<RcStr>) -> Vc<Self>
pub fn new(name: RcStr, root: Vc<RcStr>) -> Vc<Self>
Create a new instance of DiskFileSystem.
Arguments
name- Name of the filesystem.root- Path to the given filesystem’s root. Should be canonicalized.
Sourcepub fn new_with_denied_paths(
name: RcStr,
root: Vc<RcStr>,
denied_paths: Vec<RcStr>,
) -> Vc<Self>
pub fn new_with_denied_paths( name: RcStr, root: Vc<RcStr>, denied_paths: Vec<RcStr>, ) -> Vc<Self>
Create a new instance of DiskFileSystem.
Arguments
name- Name of the filesystem.root- Path to the given filesystem’s root. Should be canonicalized.denied_paths- Paths within this filesystem that are not allowed to be accessed or navigated into. These must be normalized, non-empty and relative to the fs root.