FileSystem

Trait FileSystem 

pub trait FileSystem:
    ValueToString
    + Send
    + Sync
    + NonLocalValue
    + ValueDebug {
    // Required methods
    fn read(self: Vc<Self>, fs_path: FileSystemPath) -> Vc<FileContent>
       where Self: Sized;
    fn read_link(self: Vc<Self>, fs_path: FileSystemPath) -> Vc<LinkContent>
       where Self: Sized;
    fn raw_read_dir(
        self: Vc<Self>,
        fs_path: FileSystemPath,
    ) -> Vc<RawDirectoryContent>
       where Self: Sized;
    fn write(
        self: Vc<Self>,
        fs_path: FileSystemPath,
        content: Vc<FileContent>,
    ) -> Vc<()>
       where Self: Sized;
    fn write_link(
        self: Vc<Self>,
        fs_path: FileSystemPath,
        target: Vc<LinkContent>,
    ) -> Vc<()>
       where Self: Sized;
    fn metadata(self: Vc<Self>, fs_path: FileSystemPath) -> Vc<FileMeta>
       where Self: Sized;

    // Provided method
    fn root(self: Vc<Self>) -> Vc<FileSystemPath>
       where Self: Sized { ... }
}

Required Methods

fn read(self: Vc<Self>, fs_path: FileSystemPath) -> Vc<FileContent>
where Self: Sized,

Reads the target of a symbolic link (or of a junction point on Windows).

The base of the returned LinkContent::Link target depends on the link’s LinkType: root-relative and normalized for LinkType::ABSOLUTE links, or the raw link-relative on-disk value otherwise.

Returns LinkContent::Invalid if the target points outside of the filesystem root, and LinkContent::NotFound if fs_path doesn’t exist or isn’t a link.

fn raw_read_dir( self: Vc<Self>, fs_path: FileSystemPath, ) -> Vc<RawDirectoryContent>
where Self: Sized,

fn write( self: Vc<Self>, fs_path: FileSystemPath, content: Vc<FileContent>, ) -> Vc<()>
where Self: Sized,

fn metadata(self: Vc<Self>, fs_path: FileSystemPath) -> Vc<FileMeta>
where Self: Sized,

Provided Methods

fn root(self: Vc<Self>) -> Vc<FileSystemPath>
where Self: Sized,

Returns the path to the root of the file system.